==> php83-nextcloud-28.0.2.tgz: share/nextcloud/apps/workflowengine/l10n/bg.js <==
OC.L10N.register(
    "workflowengine",
    {
    "The given operator is invalid" : "Даденият оператор е невалиден",
    "The given regular expression is invalid" : "Даденият израз е невалиден",
    "The given file size is invalid" : "Даденият размер на файла не е валиден",
    "The given tag id is invalid" : "Даденият етикет не е валиден",
    "The given IP range is invalid" : "Даденият IP диапазон е невалиден",
    "The given IP range is not valid for IPv4" : "Даденият IP диапазон не е валиден за IPv4",
    "The given IP range is not valid for IPv6" : "Даденият IP диапазон не е валиден за IPv6",
    "The given time span is invalid" : "Даденият период е невалиден",
    "The given start time is invalid" : "Даденият начален час е невалиден",
    "The given end time is invalid" : "Даденият краен час е невалиден",
    "The given group does not exist" : "Дадената група не съществува",
    "File" : "Файл",
    "File created" : "Файлът е създаден",
    "File updated" : "Файлът е актуализиран",
    "File renamed" : "Файлът е преименуван",
    "File deleted" : "Файлът е изтрит",
    "File accessed" : "Достъпен е файл",
    "File copied" : "Файлът е копиран",
    "Tag assigned" : "Присвоен е етикет",
    "Someone" : "Някой",
    "%s created %s" : "%s създаде %s",
    "%s modified %s" : "%s промени %s",
    "%s deleted %s" : "%s изтри %s",
    "%s accessed %s" : "%s достъпи %s",
    "%s renamed %s" : "%s преименува %s",
    "%s copied %s" : "%s копира %s",
    "%s assigned %s to %s" : "%s присвои %s на %s",
    "Operation #%s does not exist" : "Операция #%s не съществува",
    "Entity %s does not exist" : "Обект %s не съществува",
    "Entity %s is invalid" : "Обект %s е невалиден",
    "No events are chosen." : "Не са избрани събития.",
    "Entity %s has no event %s" : "Обект %s няма събитие %s",
    "Operation %s does not exist" : "Операция %s не съществува",
    "Operation %s is invalid" : "Операция %s е невалидна",
    "At least one check needs to be provided" : "Трябва да се предостави поне една проверка",
    "The provided operation data is too long" : "Предоставените оперативни данни са твърде дълги",
    "Invalid check provided" : "Предоставена е невалидна проверка",
    "Check %s does not exist" : "Проверка %s не съществува",
    "Check %s is invalid" : "Проверка %s е невалидна",
    "Check %s is not allowed with this entity" : "Не е позволена %s проверка с този обект",
    "The provided check value is too long" : "Предоставената стойност за проверка е твърде дълга",
    "Check #%s does not exist" : "Проверка #%s не съществува",
    "Check %s is invalid or does not exist" : "Проверка %s не е валидна или несъществува",
    "Flow" : "Поток",
    "Nextcloud workflow engine" : "Система на работния поток на Nextcloud",
    "Select a filter" : "Избор на филтър",
    "Select a comparator" : "Избор на инструмент за сравняване",
    "Select a file type" : "Избор на тип файл",
    "e.g. httpd/unix-directory" : "напр. httpd/unix-directory",
    "Folder" : "Папка",
    "Images" : "Изображения",
    "Office documents" : "Офис документи",
    "PDF documents" : "PDF документи",
    "Custom MIME type" : "Персонализиран файл тип MIME",
    "Custom mimetype" : "Персонализиран mimetype",
    "Please enter a valid time span" : "Моля, въведете валиден период от време",
    "Select a request URL" : "Избор на URL адрес за заявка",
    "Files WebDAV" : "Файлове WebDAV",
    "Custom URL" : "Персонализиран URL адрес",
    "Select a user agent" : "Избор на потребителски агент",
    "Android client" : "Android клиент",
    "iOS client" : "iOS клиент",
    "Desktop client" : "Клиент за настолен компютър",
    "Thunderbird & Outlook addons" : "Добавки на Thunderbird и Outlook",
    "Custom user agent" : "Персонализиран потребителски агент",
    "At least one event must be selected" : "Трябва да бъде избрано поне едно събитие",
    "Add new flow" : "Добавяне на нов поток",
    "When" : "Кога",
    "and" : "и",
    "Cancel" : "Отказ",
    "Delete" : "Изтриване",
    "The configuration is invalid" : "Конфигурацията е невалидна",
    "Active" : "Активен",
    "Save" : "Запази",
    "Available flows" : "Налични потоци",
    "For details on how to write your own flow, check out the development documentation." : "За подробности как да напишете свой собствен поток, вижте документацията за разработка.",
    "More flows" : "Още потоци",
    "Browse the App Store" : "Преглед на магазина за приложения /App Store/",
    "Show less" : "Покажи по-малко",
    "Show more" : "Покажи повече",
    "Configured flows" : "Конфигурирани потоци",
    "Your flows" : "Вашите потоци ",
    "matches" : "съвпадения",
    "does not match" : "не съвпада",
    "is" : "е",
    "is not" : "не е",
    "File name" : "Име на файл",
    "File MIME type" : "Тип MIME файл",
    "File size (upload)" : "Големина на файл (качване)",
    "less" : "по-малко",
    "less or equals" : "по-малко или равно",
    "greater or equals" : "по-голямо или равно",
    "greater" : "по-голям",
    "Request remote address" : "Искане на отдалечен адрес",
    "matches IPv4" : "съвпада IPv4",
    "does not match IPv4" : "не съвпада IPv4",
    "matches IPv6" : "съвпада IPv6",
    "does not match IPv6" : "не съвпада IPv6",
    "File system tag" : "Етикет на файлова система",
    "is tagged with" : "има етикет",
    "is not tagged with" : "няма етикет",
    "Request URL" : "URL на заявка",
    "Request time" : "Врене ба заявка",
    "between" : "между",
    "not between" : "не между",
    "Request user agent" : "Потребителски агент на заявка",
    "User group membership" : "Членство към потребителска група",
    "is member of" : "е член на",
    "is not member of" : "не е член на"
},
"nplurals=2; plural=(n != 1);");

==> php83-nextcloud-30.0.11.tgz: share/nextcloud/apps/workflowengine/l10n/bg.js <==
OC.L10N.register(
    "workflowengine",
    {
    "The given operator is invalid" : "Даденият оператор е невалиден",
    "The given regular expression is invalid" : "Даденият израз е невалиден",
    "The given file size is invalid" : "Даденият размер на файла не е валиден",
    "The given tag id is invalid" : "Даденият етикет не е валиден",
    "The given IP range is invalid" : "Даденият IP диапазон е невалиден",
    "The given IP range is not valid for IPv4" : "Даденият IP диапазон не е валиден за IPv4",
    "The given IP range is not valid for IPv6" : "Даденият IP диапазон не е валиден за IPv6",
    "The given time span is invalid" : "Даденият период е невалиден",
    "The given start time is invalid" : "Даденият начален час е невалиден",
    "The given end time is invalid" : "Даденият краен час е невалиден",
    "The given group does not exist" : "Дадената група не съществува",
    "File" : "Файл",
    "File created" : "Файлът е създаден",
    "File updated" : "Файлът е актуализиран",
    "File renamed" : "Файлът е преименуван",
    "File deleted" : "Файлът е изтрит",
    "File accessed" : "Достъпен е файл",
    "File copied" : "Файлът е копиран",
    "Tag assigned" : "Присвоен е етикет",
    "Someone" : "Някой",
    "%s created %s" : "%s създаде %s",
    "%s modified %s" : "%s промени %s",
    "%s deleted %s" : "%s изтри %s",
    "%s accessed %s" : "%s достъпи %s",
    "%s renamed %s" : "%s преименува %s",
    "%s copied %s" : "%s копира %s",
    "%s assigned %s to %s" : "%s присвои %s на %s",
    "Operation #%s does not exist" : "Операция #%s не съществува",
    "Entity %s does not exist" : "Обект %s не съществува",
    "Entity %s is invalid" : "Обект %s е невалиден",
    "No events are chosen." : "Не са избрани събития.",
    "Entity %s has no event %s" : "Обект %s няма събитие %s",
    "Operation %s does not exist" : "Операция %s не съществува",
    "Operation %s is invalid" : "Операция %s е невалидна",
    "At least one check needs to be provided" : "Трябва да се предостави поне една проверка",
    "The provided operation data is too long" : "Предоставените оперативни данни са твърде дълги",
    "Invalid check provided" : "Предоставена е невалидна проверка",
    "Check %s does not exist" : "Проверка %s не съществува",
    "Check %s is invalid" : "Проверка %s е невалидна",
    "Check %s is not allowed with this entity" : "Не е позволена %s проверка с този обект",
    "The provided check value is too long" : "Предоставената стойност за проверка е твърде дълга",
    "Check #%s does not exist" : "Проверка #%s не съществува",
    "Check %s is invalid or does not exist" : "Проверка %s не е валидна или несъществува",
    "Flow" : "Поток",
    "Nextcloud workflow engine" : "Система на работния поток на Nextcloud",
    "Select a filter" : "Избор на филтър",
    "Select a comparator" : "Избор на инструмент за сравняване",
    "Folder" : "Папка",
    "Images" : "Изображения",
    "Office documents" : "Офис документи",
    "PDF documents" : "PDF документи",
    "Custom MIME type" : "Персонализиран файл тип MIME",
    "Custom mimetype" : "Персонализиран mimetype",
    "Select a file type" : "Избор на тип файл",
    "e.g. httpd/unix-directory" : "напр. httpd/unix-directory",
    "Please enter a valid time span" : "Моля, въведете валиден период от време",
    "Files WebDAV" : "Файлове WebDAV",
    "Custom URL" : "Персонализиран URL адрес",
    "Select a request URL" : "Избор на URL адрес за заявка",
    "Android client" : "Android клиент",
    "iOS client" : "iOS клиент",
    "Desktop client" : "Клиент за настолен компютър",
    "Thunderbird & Outlook addons" : "Добавки на Thunderbird и Outlook",
    "Custom user agent" : "Персонализиран потребителски агент",
    "Select a user agent" : "Избор на потребителски агент",
    "Select groups" : "Избери Групи",
    "Groups" : "Групи",
    "At least one event must be selected" : "Трябва да бъде избрано поне едно събитие",
    "Add new flow" : "Добавяне на нов поток",
    "The configuration is invalid" : "Конфигурацията е невалидна",
    "Active" : "Активен",
    "Save" : "Запази",
    "When" : "Кога",
    "and" : "и",
    "Cancel" : "Отказ",
    "Delete" : "Изтриване",
    "Available flows" : "Налични потоци",
    "For details on how to write your own flow, check out the development documentation." : "За подробности как да напишете свой собствен поток, вижте документацията за разработка.",
    "More flows" : "Още потоци",
    "Browse the App Store" : "Преглед на магазина за приложения /App Store/",
    "Show less" : "Покажи по-малко",
    "Show more" : "Покажи повече",
    "Configured flows" : "Конфигурирани потоци",
    "Your flows" : "Вашите потоци ",
    "matches" : "съвпадения",
    "does not match" : "не съвпада",
    "is" : "е",
    "is not" : "не е",
    "File name" : "Име на файл",
    "File MIME type" : "Тип MIME файл",
    "File size (upload)" : "Големина на файл (качване)",
    "less" : "по-малко",
    "less or equals" : "по-малко или равно",
    "greater or equals" : "по-голямо или равно",
    "greater" : "по-голям",
    "Request remote address" : "Искане на отдалечен адрес",
    "matches IPv4" : "съвпада IPv4",
    "does not match IPv4" : "не съвпада IPv4",
    "matches IPv6" : "съвпада IPv6",
    "does not match IPv6" : "не съвпада IPv6",
    "File system tag" : "Етикет на файлова система",
    "is tagged with" : "има етикет",
    "is not tagged with" : "няма етикет",
    "Request URL" : "URL на заявка",
    "Request time" : "Врене ба заявка",
    "between" : "между",
    "not between" : "не между",
    "Request user agent" : "Потребителски агент на заявка",
    "is member of" : "е член на",
    "is not member of" : "не е член на"
},
"nplurals=2; plural=(n != 1);");
